==> scrub_2.2.orig.tar.gz: scrub-2.2/src/util.h <==
/*****************************************************************************\
 *  $Id: util.h 63 2006-01-30 18:10:01Z garlick $
 *****************************************************************************
 *  Copyright (C) 2001-2008 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Jim Garlick <garlick@llnl.gov>.
 *  UCRL-CODE-2003-006.
 *  
 *  This file is part of Scrub, a program for erasing disks.
 *  For details, see <http://www.llnl.gov/linux/scrub/>.
 *  
 *  Scrub is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *  
 *  Scrub is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with Scrub; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
\*****************************************************************************/

typedef enum { false, true } bool;

typedef enum { NOEXIST, REGULAR, CHAR, BLOCK, OTHER } filetype_t;
typedef enum { UP, DOWN } round_t;

int         read_all(int fd, unsigned char *buf, int count);
int         write_all(int fd, const unsigned char *buf, int count);
filetype_t  filetype(char *path);
off_t       blkalign(off_t offset, int blocksize, round_t rtype);

/*
 * vi:tabstop=4 shiftwidth=4 expandtab
 */

==> scrub_2.4.1.orig.tar.gz: scrub-2.4.1/src/util.h <==
/*****************************************************************************\
 *  $Id: util.h 63 2006-01-30 18:10:01Z garlick $
 *****************************************************************************
 *  Copyright (C) 2001-2008 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Jim Garlick <garlick@llnl.gov>.
 *  UCRL-CODE-2003-006.
 *  
 *  This file is part of Scrub, a program for erasing disks.
 *  For details, see <http://www.llnl.gov/linux/scrub/>.
 *  
 *  Scrub is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *  
 *  Scrub is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with Scrub; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
\*****************************************************************************/

typedef enum { false, true } bool;

typedef enum { NOEXIST, REGULAR, CHAR, BLOCK, LINK, OTHER } filetype_t;
typedef enum { UP, DOWN } round_t;

int         read_all(int fd, unsigned char *buf, int count);
int         write_all(int fd, const unsigned char *buf, int count);
filetype_t  filetype(char *path);
off_t       blkalign(off_t offset, int blocksize, round_t rtype);

/*
 * vi:tabstop=4 shiftwidth=4 expandtab
 */
